/****************************************************************************
** Meta object code from reading C++ file 'bag_widget.h'
**
** Created: Fri Jan 1 10:33:19 2010
**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qt/bag_widget.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bag_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 61
#error "This file was generated using the moc from 4.5.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_BagWidget[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // slots: signature, parameters, type, tag, flags
      17,   11,   10,   10, 0x0a,
      44,   10,   10,   10, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_BagWidget[] = {
    "BagWidget\0\0iGame\0setGame(const PublicGame*)\0"
    "refresh()\0"
};

const QMetaObject BagWidget::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_BagWidget,
      qt_meta_data_BagWidget, 0 }
};

const QMetaObject *BagWidget::metaObject() const
{
    return &staticMetaObject;
}

void *BagWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_BagWidget))
        return static_cast<void*>(const_cast< BagWidget*>(this));
    return QTreeView::qt_metacast(_clname);
}

int BagWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: setGame((*reinterpret_cast< const PublicGame*(*)>(_a[1]))); break;
        case 1: refresh(); break;
        default: ;
        }
        _id -= 2;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
